==> Zephyrus-3.2.6.11569.tar.gz: Zephyrus-3.2.6.11569/Zephyrus/comment/models.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: models.py 11502 2019-05-01 05:37:40Z Lavender $
#
# Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $
# $Date: 2019-05-01 14:37:40 +0900 (週三, 01 五月 2019) $
# $Revision: 11502 $

import datetime

from django.db import models
from django.conf import settings
from django.utils.translation import ugettext_lazy as _
from cms.models import CMSPlugin

from Zephyrus.comment import settings as _settings

class CommentPlugin(CMSPlugin):
    useFbComment = models.BooleanField(_('Use Facebook Comment'))
    
    emailTo = models.CharField(
        _('Send form data to e-mail address'), max_length=255, blank=True,
        help_text=_('Separate several addresses with a comma.'), default=""
    )

    renderTemplate = models.CharField(
        _('Comment Template'), max_length=150,
        choices=_settings.ZEPHYRUS_COMMENT_TEMPLATES,
        default=_settings.ZEPHYRUS_COMMENT_DEFAULT_TEMPLATE,
    )

class RecentResponsePlugin(CMSPlugin):
    limit = models.PositiveIntegerField(default=6)

    renderTemplate = models.CharField(
        _('Comment Template'), max_length=150,
        choices=_settings.ZEPHYRUS_RECENTRESPONSE_TEMPLATES,
        default=_settings.ZEPHYRUS_RECENTRESPONSE_DEFAULT_TEMPLATE,
    )

class Comment(models.Model):
    url = models.CharField(max_length=400, editable=False, null=True)
    
    user = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, blank=True)
    email = models.EmailField(max_length=254, null=True, blank=True)

    message = models.TextField()

    createDate = models.DateTimeField(auto_now_add=True)
    display = models.BooleanField(default=True)
    
    @property
    def username(self):
        if self.user:
            return self.user.username
        else:
            return self.email

class CommentConfig(models.Model):
    url = models.CharField(max_length=400, editable=False, null=True)
    useFbComment = models.BooleanField(_('Use Facebook Comment'))

==> Zephyrus-3.3.0.11589.tar.gz: Zephyrus-3.3.0.11589/Zephyrus/comment/models.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: models.py 11593 2019-05-29 06:23:49Z Lavender $
#
# Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $
# $Date: 2019-05-29 15:23:49 +0900 (週三, 29 五月 2019) $
# $Revision: 11593 $

import datetime

from django.db import models
from django.conf import settings
from django.core.exceptions import ValidationError
from django.utils.translation import ugettext_lazy as _
from cms.models import CMSPlugin

from Zephyrus.comment import settings as _settings

class CommentPlugin(CMSPlugin):
    useFbComment = models.BooleanField(_('Use Facebook Comment'))

    appId = models.CharField(
        _("Facebook API app ID"), max_length=20, null=True, blank=True)
    
    emailTo = models.CharField(
        _('Send form data to e-mail address'), max_length=255, blank=True,
        help_text=_('Separate several addresses with a comma.'), default=""
    )

    renderTemplate = models.CharField(
        _('Comment Template'), max_length=150,
        choices=_settings.ZEPHYRUS_COMMENT_TEMPLATES,
        default=_settings.ZEPHYRUS_COMMENT_DEFAULT_TEMPLATE,
    )

    def clean(self):
        if self.useFbComment:
            if not self.appId:
                raise ValidationError(
                        _('When use facebook comment plugin'
                        ', you should set facebook app id.')
                      )

class RecentResponsePlugin(CMSPlugin):
    limit = models.PositiveIntegerField(default=6)

    renderTemplate = models.CharField(
        _('Comment Template'), max_length=150,
        choices=_settings.ZEPHYRUS_RECENTRESPONSE_TEMPLATES,
        default=_settings.ZEPHYRUS_RECENTRESPONSE_DEFAULT_TEMPLATE,
    )

class Comment(models.Model):
    url = models.CharField(max_length=400, editable=False, null=True)
    
    user = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, blank=True)
    email = models.EmailField(max_length=254, null=True, blank=True)
    
    message = models.TextField()

    createDate = models.DateTimeField(auto_now_add=True)
    display = models.BooleanField(default=True)

    facebook = models.BooleanField(default=False)
    facebookUser = models.CharField(max_length=128, editable=False, null=True)
    
    @property
    def username(self):
        if not self.facebook:
            if self.user:
                return self.user.username
            else:
                return self.email
        else:
            return self.facebookUser


class CommentConfig(models.Model):
    url = models.CharField(max_length=400, editable=False, null=True)
    useFbComment = models.BooleanField(_('Use Facebook Comment'))
